@@ -6,9 +6,11 @@ format_two_digits <- function(x) {
   formatC(x, format = "f", digits = 0, width = 2, flag = "0")
 }
 
-format_split_seconds <- function(x) {
-  out <- format(x, scientific = FALSE)
-  digits <- max(min(max(nchar(out) - 2), 6), 0)
+format_tics <- function(x) {
+  x <- x / TICS_PER_SECOND
+
+  out <- format(x, scientific = FALSE, digits = SPLIT_SECOND_DIGITS + 1L)
+  digits <- max(min(max(nchar(out) - 2), SPLIT_SECOND_DIGITS), 0)
   out <- formatC(x, format = "f", digits = digits)
   gsub("^0", "", out)
 }
