@@ -1,13 +1,3 @@
-#' @details
-#' `r lifecycle::badge("stable")`
-#' @importFrom lifecycle deprecate_soft expect_deprecated
-#' @import vctrs
-#' @import rlang
-#' @import ellipsis
-#' @aliases hms-package NULL
-"_PACKAGE"
-
-#' @importFrom methods setOldClass
 setOldClass(c("hms", "difftime"))
 
 #' A simple class for storing time-of-day values
@@ -45,18 +35,31 @@ NULL
 #' as numeric vectors.
 #'
 #' @rdname hms
-#' @details For `hms`, all arguments must have the same length or be
+#' @details For `hms()`, all arguments must have the same length or be
 #'   `NULL`.  Odd combinations (e.g., passing only `seconds` and
 #'   `hours` but not `minutes`) are rejected.
 #' @param seconds,minutes,hours,days Time since midnight. No bounds checking is
 #'   performed.
 #' @export
 hms <- function(seconds = NULL, minutes = NULL, hours = NULL, days = NULL) {
-  args <- list(seconds = seconds, minutes = minutes, hours = hours, days = days)
-  check_args(args)
+  error_call <- caller_env()
+  args <- list(
+    seconds = seconds,
+    minutes = minutes,
+    hours = hours,
+    days = days
+  )
+
+  args_df <- data_frame(!!!args, .error_call = error_call)
+  args[names(args_df)] <- as.list(args_df)
+
+  check_args(args, error_call)
+
   arg_secs <- map2(args, c(1, 60, 3600, 86400), `*`)
   secs <- reduce(arg_secs[!map_lgl(args, is.null)], `+`)
-  if (is.null(secs)) secs <- numeric()
+  if (is.null(secs)) {
+    secs <- numeric()
+  }
 
   new_hms(as.numeric(secs))
 }
@@ -99,17 +102,17 @@ NULL
 #' @export
 #' @keywords internal
 is.hms <- function(x) {
-  deprecate_soft("0.5.0", "hms::is.hms()", "hms::is_hms()")
+  deprecate_warn("1.2.0", "hms::is.hms()", "hms::is_hms()")
   is_hms(x)
 }
 
 #' @export
-vec_ptype_abbr.hms <- function(x) {
+vec_ptype_abbr.hms <- function(x, ...) {
   "time"
 }
 
 #' @export
-vec_ptype_full.hms <- function(x) {
+vec_ptype_full.hms <- function(x, ...) {
   "time"
 }
 
@@ -149,7 +152,7 @@ as_hms.default <- function(x, ...) {
 #' @export
 #' @keywords internal
 as.hms <- function(x, ...) {
-  deprecate_soft("0.5.0", "hms::as.hms()", "hms::as_hms()")
+  deprecate_warn("1.2.0", "hms::as.hms()", "hms::as_hms()")
   UseMethod("as.hms", x)
 }
 
@@ -166,15 +169,22 @@ as.hms.default <- function(x, ...) {
 #'   `pkgconfig::set_config("hms::default_tz", "UTC")`, see
 #'   [pkgconfig::set_config()].
 #' @export
-#' @importFrom pkgconfig get_config
-as.hms.POSIXt <- function(x, tz = pkgconfig::get_config("hms::default_tz", ""), ...) {
+as.hms.POSIXt <- function(
+  x,
+  tz = pkgconfig::get_config("hms::default_tz", ""),
+  ...
+) {
   time <- as.POSIXlt(x, tz = tz)
   vec_cast(time, new_hms())
 }
 
 #' @rdname Deprecated
 #' @export
-as.hms.POSIXlt <- function(x, tz = pkgconfig::get_config("hms::default_tz", ""), ...) {
+as.hms.POSIXlt <- function(
+  x,
+  tz = pkgconfig::get_config("hms::default_tz", ""),
+  ...
+) {
   # We need to roundtrip via as.POSIXct() to respect the time zone
   time <- as.POSIXlt(as.POSIXct(x), tz = tz)
   vec_cast(time, new_hms())
@@ -205,12 +215,19 @@ as.character.hms <- function(x, ...) {
 format_hms <- function(x) {
   xx <- decompose(x)
 
-  ifelse(is.na(x), NA_character_, paste0(
-    ifelse(xx$sign, "-", ""),
-    format_hours(xx$hours), ":",
-    format_two_digits(xx$minute_of_hour), ":",
-    format_two_digits(xx$second_of_minute),
-    format_tics(xx$tics)))
+  ifelse(
+    is.na(x),
+    NA_character_,
+    paste0(
+      ifelse(xx$sign, "-", ""),
+      format_hours(xx$hours),
+      ":",
+      format_two_digits(xx$minute_of_hour),
+      ":",
+      format_two_digits(xx$second_of_minute),
+      format_tics(xx$tics)
+    )
+  )
 }
 
 
@@ -251,7 +268,7 @@ c.hms <- function(x, ...) {
 #' @export
 `units<-.hms` <- function(x, value) {
   if (!identical(value, "secs")) {
-    warning("hms always uses seconds as unit.", call. = FALSE)
+    cli_warn("{.pkg hms} always uses seconds as unit.")
   }
   x
 }
@@ -275,3 +292,38 @@ print.hms <- function(x, ...) {
   cat(format(x), sep = "\n")
   invisible(x)
 }
+
+# Sequence generation -----------------
+
+#' @rdname hms
+#' @inheritParams base::seq
+#' @export
+seq.hms <- function(
+  from = hms(1),
+  to = hms(1),
+  by = NULL,
+  ...
+) {
+  if (!is_hms(to)) {
+    abort(sprintf(
+      "`to` isn't of class `hms` (current class: `%s`).",
+      class(to)[1]
+    ))
+  }
+
+  from <- vec_cast(as_hms(from), numeric())
+  to <- vec_cast(as_hms(to), numeric())
+
+  if (!is.null(by)) {
+    if (!(is_hms(by) || inherits(by, "difftime"))) {
+      abort(sprintf(
+        "`by` isn't of class `hms` or `difftime` (current class: `%s`).",
+        class(by)[1]
+      ))
+    }
+    by <- vec_cast(as_hms(by), numeric())
+    return(hms(seq(from, to, by, ...)))
+  }
+
+  hms(seq(from, to, ...))
+}
