@@ -6,10 +6,16 @@ empty_tz <- function(x) {
 test_that("arithmetics work", {
   expect_equal(as.Date("2016-03-31") + hms(hours = 1), as.Date("2016-03-31"))
   expect_equal(as.Date("2016-03-31") + hms(days = -1), as.Date("2016-03-30"))
-  expect_equal(empty_tz(as.POSIXct("2016-03-31") + hms(1)), as.POSIXct("2016-03-31 00:00:01"))
+  expect_equal(
+    empty_tz(as.POSIXct("2016-03-31") + hms(1)),
+    as.POSIXct("2016-03-31 00:00:01")
+  )
   expect_equal(hms(hours = 1) + as.Date("2016-03-31"), as.Date("2016-03-31"))
   expect_equal(hms(days = 1) + as.Date("2016-03-31"), as.Date("2016-04-01"))
-  expect_equal(empty_tz(hms(hours = 1) + as.POSIXct("2016-03-31")), as.POSIXct("2016-03-31 01:00:00"))
+  expect_equal(
+    empty_tz(hms(hours = 1) + as.POSIXct("2016-03-31")),
+    as.POSIXct("2016-03-31 01:00:00")
+  )
 
   expect_difftime_equal(hms(1) + hms(2), hms(3))
   expect_difftime_equal(hms(1) - hms(2), hms(-1))
